/* 
 *  This code developed for interfacing an Arduino with the 
 *  wind vane included in the ADS Wind / Rain Sensor Assembly 
 *  https://www.argentdata.com/catalog/product_info.php?products_id=145
 *  and requires a fixed 10kOhm resistor. This code works with a 3.3V 
 *  or 5V signal.
 *  
 *  This code only reports instantaneous wind direction in angle format. For a more 
 *  robust solution that takes into account consensus averaging, please
 *  consider reviewing John Cape's library available here:
 *  https://www.arduinolibraries.info/libraries/ads-weather
 *  
 *  Prpeared by Hans Huth and licensed under Creative Commons. 
 *  No guarantees implied.
 *  
 *  1/6/2020
*/


#define windDir A0 // pin tied to Vout for voltage divider circuit

// These arrays are specific to the ADS wind vane with a 10kOhm fixed resistor in the voltage divider
int sensorExp[] = {66,84,93,126,184,244,287,406,461,599,630,702,785,827,886,945};
float dirDeg[] = {112.5,67.5,90,157.5,135,202.5,180,22.5,45,247.5,225,337.5,0,292.5,315,270};
char* dirCard[] = {"ESE","ENE","E","SSE","SE","SSW","S","NNE","NE","WSW","SW","NNW","N","WNW","NW","W"};

int sensorMin[] = {63,80,89,120,175,232,273,385,438,569,613,667,746,812,869,931};
int sensorMax[] = {69,88,98,133,194,257,301,426,484,612,661,737,811,868,930,993};

int incoming = 0;
float angle = 0;

void setup() {
Serial.begin(9600);
}

void loop() {
  incoming = analogRead(windDir);
  for(int i=0; i<=15; i++) {
   if(incoming >= sensorMin[i] && incoming <= sensorMax[i]) {
    angle = dirDeg[i];
    break;
   } 
  }
  
  Serial.print(angle);
  Serial.print(":");
  delay(25);
}
