/*  
 *  This code was derived from John Cape's ADS library for interfacing 
 *  an Arduino with the ADS Wind / Rain Sensor Assembly 
 *  https://www.arduinolibraries.info/libraries/ads-weather
 *  https://www.argentdata.com/catalog/product_info.php?products_id=145
 *  
 *  This sketch interfaces wtih a tipping bucket rain gauge by reporting 
 *  total tips as a foundation to better understand John's 
 *  library. 
 *  
 *  Prepared by Hans Huth
 *  1/6/2020
 */


// The bucket tested with this code is summarized here:
// http://texaselectronics.com/media/mconnect_uploadfiles/t/r/tr-525i_rainfall_user_s_manual.pdf

// Testing shows this bucket has a normally open reed switch.

#define RAIN_PIN 3          // replace with your microcontrollers interrupt pin number tied to your rain gauge
#define CALC_INTERVAL 1000  // increment of measurements
#define DEBOUNCE_TIME 15    // referenced in ISR; multiply by 1000 if using a reed switch

unsigned long nextCalc;
unsigned long timer;

volatile unsigned int rainTrigger = 0;
volatile unsigned long last_micros_rg;

void setup() {
  Serial.begin(9600); 
  attachInterrupt(digitalPinToInterrupt(RAIN_PIN), countingRain, RISING); 
  
  pinMode(RAIN_PIN, INPUT);
  nextCalc = millis() + CALC_INTERVAL;
}

void loop() {
  timer = millis();
  if(timer > nextCalc) {
    nextCalc = timer + CALC_INTERVAL;
    Serial.print("Total Tips: ");
    Serial.println((float) rainTrigger);     
  }
}

void countingRain() {
  // ATTEMPTED: Check to see if time since last interrupt call is greater than 
  // debounce time. If so, then the last interrupt call is through the 
  // noisy period of the reed switch bouncing, so we can increment by one.   
  if((long)(micros() - last_micros_rg) >= DEBOUNCE_TIME) { 
   rainTrigger += 1;
   last_micros_rg = micros();
  }  
}



