/*  
 *  This code was derived from John Cape's ADS library for interfacing 
 *  an Arduino with the ADS Wind / Rain Sensor Assembly 
 *  https://www.arduinolibraries.info/libraries/ads-weather
 *  https://www.argentdata.com/catalog/product_info.php?products_id=145
 *  
 *  This sketch interfaces wtih an anemometer. This sketch only reports 
 *  instantaneous measurements as a foundation to better understand John's 
 *  library. 
 *  
 *  Prepared by Hans Huth
 *  1/6/2020
 */

#define DEBOUNCE_TIME 15
#define CALC_INTERVAL 1000
#define ANEMOMETER_PIN 3 // Interrupt pin tied to anemometer reed switch

unsigned long _nextCalc;
unsigned long _timer;

volatile int _anemometerCounter;
volatile unsigned long last_micros_an;

int _windSpd;

void setup() {
 Serial.begin(9600);
 
 pinMode(ANEMOMETER_PIN, INPUT);
 attachInterrupt(digitalPinToInterrupt(ANEMOMETER_PIN), countAnemometer, FALLING); 
}

void loop() {
 _timer = millis();
  
 if(_timer > _nextCalc) {
  _nextCalc = _timer + CALC_INTERVAL;
  //UPDATE ALL VALUES
  _windSpd = readWindSpd();
  Serial.print(_windSpd);
  Serial.print(":");    
 }
}

//returns the wind speed since the last calcInterval.
int readWindSpd() {
 unsigned char i;  
 long spd = 14920; // one turn = 1.492 miles per hour; modify as necessary for your instrument
 spd *= _anemometerCounter;
 spd /= 10000;
 _anemometerCounter = 0;
 return (int) spd;
}

void countAnemometer() {
 if((long)(micros() - last_micros_an) >= DEBOUNCE_TIME * 1000) {
    _anemometerCounter++;
    last_micros_an = micros();
 }
}


